@@ -1,11 +1,13 @@
-__version__ = "0.2.7"
+__version__ = "0.3.1"
 
 from multiprocessing import Manager
-from time import time
 
-start_time = time()
 share_manager = Manager()
 
 
 class CrawlException(Exception):
     ...
+
+
+class ActionException(Exception):
+    ...
