@@ -3,3 +3,5 @@ OUTPUT_LIST = "l"
 CRAWL_MODE = "M"
 MODE_SIMPLE = "s"
 MODE_EXTENDED = "e"
+HIT = "h"
+LINK = "l"
